//
//  GameLayer.m
//  ScenesAndLayers_Cocos2D
//
//  Created by Du Yabo on 11-12-8.
//  Copyright 2011年 Beijing Mobroad Tech Co.Ltd. All rights reserved.
//

#import "GameLayer.h"
#import "MultiLayerScene.h"
#import "Spider.h"

@interface GameLayer (PrivateMethods)
-(void)addRandomThings;
-(void)runRandomMoveSequence:(CCNode*)node;
@end


@implementation GameLayer

-(id) init
{
    if(self=[super init]){
        gameLayerLocation=self.position;
        
        CGSize screenSize=[[CCDirector sharedDirector] winSize];
        CCSprite *background=[CCSprite spriteWithFile:@"grass.png"];
        background.position=CGPointMake(screenSize.width/2, screenSize.height/2);
        [self addChild:background];
        
        CCLabelTTF *label=[CCLabelTTF labelWithString:@"Game Layer" fontName:@"Marker Felt" fontSize:44];
        label.position=CGPointMake(screenSize.width/2, screenSize.height/2);
        label.anchorPoint=CGPointMake(0.5f, 1.0f);
        [self addChild:label];
        
        [self addRandomThings];
        
        self.isTouchEnabled=YES;
        
    }
    return self;
}

-(void) addRandomThings
{
    CGSize screenSize=[[CCDirector sharedDirector] winSize];
    
    for(int i=0;i<4;i++){
        CCSprite *sprite=[CCSprite spriteWithFile:@"firething.png"];
        sprite.position=CGPointMake(CCRANDOM_0_1()*screenSize.width, CCRANDOM_0_1()*screenSize.height);
        [self runRandomMoveSequence:sprite];
        [self addChild:sprite];
    }
    
    for (int i=0; i<10; i++) {
        //CCSprite *sprite=[CCSprite spriteWithFile:@"spider.png"];
        //sprite.position=CGPointMake(CCRANDOM_0_1()*screenSize.width, CCRANDOM_0_1()*screenSize.height);
        //[self addChild:spider];
        [Spider spiderWithParentNode:self];
        //[self runRandomMoveSequence:spider];
    }
}

-(void) runRandomMoveSequence:(CCNode *)node
{
    float duration=CCRANDOM_0_1()*5+1;
    CCMoveBy *move1=[CCMoveBy actionWithDuration:duration position:CGPointMake(-180, 0)];
    CCMoveBy *move2=[CCMoveBy actionWithDuration:duration position:CGPointMake(0, -180)];
    CCMoveBy *move3=[CCMoveBy actionWithDuration:duration position:CGPointMake(180, 0)];
    CCMoveBy *move4=[CCMoveBy actionWithDuration:duration position:CGPointMake(0, 180)];
    CCSequence *sequence=[CCSequence actions:move1,move2,move3,move4, nil];
    CCRepeatForever *repeat=[CCRepeatForever actionWithAction:sequence];
    [node runAction:repeat];
}


-(void) registerWithTouchDispatcher
{
    [[CCTouchDispatcher sharedDispatcher] addTargetedDelegate:self priority:0 swallowsTouches:YES];
}

-(BOOL) ccTouchBegan:(UITouch *)touch withEvent:(UIEvent *)event
{
    //记录开始touch时的位置
    lastTouchLocation=[MultiLayerScene locationFromTouch:touch];
    
    //在每次touch动作开始时，先停止之前的touch对象
    [self stopActionByTag:ActionTagGameLayerMovesBack];
    return YES;
}

-(void) ccTouchMoved:(UITouch *)touch withEvent:(UIEvent *)event
{
    //记录当前移动时的touch位置
    CGPoint currentLocation=[MultiLayerScene locationFromTouch:touch];
    //取得当前touch位置与开始touch位置之差
    CGPoint moveTo=ccpSub(lastTouchLocation, currentLocation);
    moveTo=ccpMult(moveTo, -1);
    
    //记录当前touch位置为最后一次touch位置
    lastTouchLocation=currentLocation;
    //移动画布层到当前touch位置
    self.position=ccpAdd(self.position, moveTo);
}

-(void) ccTouchEnded:(UITouch *)touch withEvent:(UIEvent *)event
{
    //将画布层恢复到初始位置
    CCMoveTo *moveTo=[CCMoveTo actionWithDuration:1 position:gameLayerLocation];
    CCEaseIn *ease=[CCEaseIn actionWithAction:moveTo rate:0.5f];
    ease.tag=ActionTagGameLayerMovesBack;
    [self runAction:ease];
}

-(void) dealloc
{
    [super dealloc];
}

@end
