//
//  ParallaxScene.m
//  ScenesAndLayers_Cocos2D
//
//  Created by Du Yabo on 11-12-11.
//  Copyright 2011年 Beijing Mobroad Tech Co.Ltd. All rights reserved.
//

#import "ParallaxScene.h"
#import "ColorLayer.h"
#import "MultiLayerScene.h"

@interface ParallaxScene (PivateMethods)
-(void)resetRibbon;
-(CCRibbon*)getRibbon;
-(void)addRibbon:(CGPoint)location;
-(void)resetMotionStreak;
-(CCMotionStreak*) getMotionStreak;
-(void)addMotionStreak:(CGPoint)location;
@end

@implementation ParallaxScene

+(id) scene
{
    CCScene *scene=[CCScene node];
    ParallaxScene *layer=[ParallaxScene node];
    [scene addChild:layer];
    return scene;
}

-(id) init
{
    if(self=[super init]){
        ColorLayer *colorLayer=[ColorLayer layerWithColor:ccc4(255, 0, 255, 255)];
        [self addChild:colorLayer z:0];
        
        CGSize screenSize=[[CCDirector sharedDirector] winSize];
        CCSprite *para1=[CCSprite spriteWithFile:@"parallax1.png"];
        CCSprite *para2=[CCSprite spriteWithFile:@"parallax2.png"];
        CCSprite *para3=[CCSprite spriteWithFile:@"parallax3.png"];
        CCSprite *para4=[CCSprite spriteWithFile:@"parallax4.png"];
        
        para1.anchorPoint=CGPointMake(0, 1);
        para2.anchorPoint=CGPointMake(0, 1);
        para3.anchorPoint=CGPointMake(0, 0.6f);
        para4.anchorPoint=CGPointMake(0, 0);
        CGPoint topOffset=CGPointMake(0, screenSize.height);
        CGPoint midOffset=CGPointMake(0, screenSize.height/2);
        CGPoint downOffset=CGPointZero;
        
        //创建视差图层组并添加其子节点，指点子节点移动比率
        CCParallaxNode *parallax=[CCParallaxNode node];
        [parallax addChild:para1 z:1 parallaxRatio:CGPointMake(0.5f, 0) positionOffset:topOffset];
        [parallax addChild:para2 z:2 parallaxRatio:CGPointMake(1, 0) positionOffset:topOffset];
        [parallax addChild:para3 z:4 parallaxRatio:CGPointMake(3, 0) positionOffset:midOffset];
        [parallax addChild:para4 z:3 parallaxRatio:CGPointMake(4, 0) positionOffset:downOffset];
        [self addChild:parallax z:0 tag:ParallaxSceneTagParallaxNode];
        
        //为视差图层添加循环移动动作
        CCMoveBy *move1=[CCMoveBy actionWithDuration:5 position:CGPointMake(-120, 0)];
        CCMoveBy *move2=[CCMoveBy actionWithDuration:15 position:CGPointMake(120, 0)];
        CCSequence *sequence=[CCSequence actions:move1,move2, nil];
        CCRepeatForever *repeat=[CCRepeatForever actionWithAction:sequence];
        [parallax runAction:repeat];
        
        self.isTouchEnabled=YES;
        
        [self resetMotionStreak];
    }
    return self;
}

//重置Ribbon为初始状态
-(void) resetRibbon
{
    [self removeChildByTag:ParallaxSceneTagRibbon cleanup:YES];
    CCRibbon *ribbon=[CCRibbon ribbonWithWidth:32 image:@"spider.png" length:32 color:ccc4(255, 255, 255, 255) fade:0.5f];
    [self addChild:ribbon z:5 tag:ParallaxSceneTagRibbon];
}

//通过标签来获取Ribbon对象
-(CCRibbon*) getRibbon
{
    CCNode *node=[self getChildByTag:ParallaxSceneTagRibbon];
    return (CCRibbon*)node;
}

//在给定点添加Ribbon对象
-(void) addRibbonPoint:(CGPoint)point
{
    CCRibbon *ribbon=[self getRibbon];
    [ribbon addPointAt:point width:32];
}


-(void) resetMotionStreak
{
    [self removeChildByTag:ParallaxSceneTagRibbon cleanup:YES];
    CCMotionStreak *motionStreak=[CCMotionStreak streakWithFade:0.8f minSeg:10 image:@"spider.png" width:32 length:32 color:ccc4(255, 0, 255, 255)];
    [self addChild:motionStreak z:10 tag:ParallaxSceneTagRibbon];
}

-(CCMotionStreak*) getMotionStreak
{
    CCNode *node=[self getChildByTag:ParallaxSceneTagRibbon];
    return (CCMotionStreak*)node;
}

-(void) addMotionStreak:(CGPoint)location
{
    CCMotionStreak *motionStreak=[self getMotionStreak];
    [motionStreak.ribbon addPointAt:location width:32];
}

-(void) registerWithTouchDispatcher
{
    [[CCTouchDispatcher sharedDispatcher] addTargetedDelegate:self priority:0 swallowsTouches:YES];
}

//在touch开始点添加Ribbon对象
-(BOOL) ccTouchBegan:(UITouch *)touch withEvent:(UIEvent *)event
{
    //[self addRibbonPoint:[MultiLayerScene locationFromTouch:touch]];
    [self addMotionStreak:[MultiLayerScene locationFromTouch:touch]];
    return YES;
}

//在touch移动时添加Ribbon对象
-(void) ccTouchMoved:(UITouch *)touch withEvent:(UIEvent *)event
{
    //[self addRibbonPoint:[MultiLayerScene locationFromTouch:touch]];
    [self addMotionStreak:[MultiLayerScene locationFromTouch:touch]];
}

//在touch事件结束时重置Ribbon对象
-(void) ccTouchEnded:(UITouch *)touch withEvent:(UIEvent *)event
{
    //[self resetRibbon];
}

-(void) dealloc
{
    [super dealloc];
}

@end
