//
//  Spider.m
//  ScenesAndLayers_Cocos2D
//
//  Created by Du Yabo on 11-12-11.
//  Copyright 2011年 Beijing Mobroad Tech Co.Ltd. All rights reserved.
//

#import "Spider.h"
#import "MultiLayerScene.h"

@implementation Spider

+(id) spiderWithParentNode:(CCNode *)parentNode
{
    return [[[self alloc] initWithParentNode:parentNode] autorelease];
}

-(id) initWithParentNode:(CCNode *)parentNode
{
    if(self=[super init]){
        [parentNode addChild:self];
        
        CGSize screenSize=[[CCDirector sharedDirector] winSize];
        spiderSprite=[CCSprite spriteWithFile:@"spider.png"];
        spiderSprite.position=CGPointMake(CCRANDOM_0_1()*screenSize.width, CCRANDOM_0_1()*screenSize.height);
        [self addChild:spiderSprite];
        
        //每帧对此对象进行更新
        [self scheduleUpdate];
        
        //手动注册以target方式来响应touch事件
        [[CCTouchDispatcher sharedDispatcher] addTargetedDelegate:self priority:-1 swallowsTouches:YES];
    }
    return self;
}

-(void) moveAway:(float)duration position:(CGPoint)moveTo
{
    //本帧更新前，停止之前所有帧附加在精灵上的动作
    [spiderSprite stopAllActions];
    
    CCMoveBy *move=[CCMoveBy actionWithDuration:duration position:moveTo];
    [spiderSprite runAction:move];
}

-(void) update:(ccTime)delta
{
    numberUpdates++;
    //每50次更新来处理一次精灵移动
    if(numberUpdates>50){
        numberUpdates=0;
        
        CGPoint moveTo=CGPointMake(CCRANDOM_0_1()*200-100, CCRANDOM_0_1()*100-50);
        [self moveAway:2 position:moveTo];
    }
}

-(BOOL)ccTouchBegan:(UITouch *)touch withEvent:(UIEvent *)event
{
    //判断是否在spider图像范围内接收到了touch事件
    CGPoint touchLocation=[MultiLayerScene locationFromTouch:touch];
    BOOL isTouchHandled=CGRectContainsPoint([spiderSprite boundingBox], touchLocation);
    
    if(isTouchHandled){
        numberUpdates=0;
        
        CGPoint moveTo;
        float moveDistance=60;
        float rand=CCRANDOM_0_1();
        
        if(rand<0.25f){
            moveTo=CGPointMake(moveDistance, moveDistance);
        }else if(rand<0.5f){
            moveTo=CGPointMake(moveDistance, -moveDistance);
        }else if(rand<0.75f){
            moveTo=CGPointMake(-moveDistance, moveDistance);
        }else{
            moveTo=CGPointMake(-moveDistance, -moveDistance);
        }
        
        [self moveAway:0.1f position:moveTo];
    }
    
    return isTouchHandled;
}

-(void) dealloc
{
    //由于之前手动注册了touch事件处理的委托，此处必须手动来移除它
    [[CCTouchDispatcher sharedDispatcher] removeDelegate:self];
    [super dealloc];
}

@end
