//
//  UserInterfaceLayer.m
//  ScenesAndLayers_Cocos2D
//
//  Created by Du Yabo on 11-12-8.
//  Copyright 2011年 Beijing Mobroad Tech Co.Ltd. All rights reserved.
//

#import "UserInterfaceLayer.h"
#import "GameLayer.h"
#import "MultiLayerScene.h"

@implementation UserInterfaceLayer

-(id) init
{
    if(self=[super init]){
        CGSize screenSize=[[CCDirector sharedDirector] winSize];
        CCSprite *uiframe=[CCSprite spriteWithFile:@"ui-frame.png"];
        uiframe.anchorPoint=CGPointMake(0, 1);
        uiframe.position=CGPointMake(0, screenSize.height);
        uiframe.tag=UILayerTagFrameSprite;
        [self addChild:uiframe];
        
        CCLabelTTF *label=[CCLabelTTF labelWithString:@"Here be your Game Scores etc" fontName:@"Courier" fontSize:22];
        label.anchorPoint=CGPointMake(0.5f, 1);
        label.position=CGPointMake(screenSize.width/2, screenSize.height);
        [self addChild:label];
        
        CCProgressTimer *progress=[CCProgressTimer progressWithFile:@"firething.png"];
        progress.type=kCCProgressTimerTypeRadialCW;
        progress.position=CGPointMake(240, screenSize.height/2);
        progress.percentage=0;
        progress.scale=4;
        //不可修改其anchorPoint属性，否则进度条效果将会出现问题
        //progress.anchorPoint=CGPointMake(0.5f, 1);
        [self addChild:progress z:1 tag:UILayerTagProgressTimer];
        [self scheduleUpdate];
        
        self.isTouchEnabled=YES;
    }
    return self;
}

-(void) update:(ccTime)delta
{
    CCNode *node=[self getChildByTag:UILayerTagProgressTimer];
    CCProgressTimer *progress=(CCProgressTimer*)node;
    
    //随时间增长而增加进度百分比，此处在处理percentage时要注意=>100
    progress.percentage+=delta*10;
    if(progress.percentage>=100){
        progress.percentage=0;
    }
}

-(bool) isTouchForMe:(CGPoint)location
{
    CCNode *node=[self getChildByTag:UILayerTagFrameSprite];
    //判断给定点是否在当前的节点区域
    return CGRectContainsPoint([node boundingBox], location);
}

-(void) registerWithTouchDispatcher{
    //此处的priority越小，响应touch事件的优先级越高
    [[CCTouchDispatcher sharedDispatcher] addTargetedDelegate:self priority:-1 swallowsTouches:YES];
}

-(BOOL) ccTouchBegan:(UITouch *)touch withEvent:(UIEvent *)event
{
    CGPoint location=[MultiLayerScene locationFromTouch:touch];
    bool isTouchHandled=[self isTouchForMe:location];
    if(isTouchHandled){
        CCNode *node=[self getChildByTag:UILayerTagFrameSprite];
        ((CCSprite*)node).color=ccRED;
        
        //旋转与缩放动作
        CCRotateBy *rotate=[CCRotateBy actionWithDuration:4 angle:360];
        CCScaleTo *scaleDown=[CCScaleTo actionWithDuration:2 scale:0];
        CCScaleTo *scaleUp=[CCScaleTo actionWithDuration:2 scale:1];
        CCSequence *sequence=[CCSequence actions:rotate,scaleDown,scaleUp, nil];
        sequence.tag=ActionTagGameLayerRotates;
        
        GameLayer *gameLayer=[MultiLayerScene sharedLayer].gameLayer;
        //在每次执行动作前，注意要停止前一次执行动作，恢复精灵到原始状态
        [gameLayer stopActionByTag:ActionTagGameLayerRotates];
        [gameLayer setRotation:0];
        [gameLayer setScale:1];
        [gameLayer runAction:sequence];
        
    }
    return isTouchHandled;
}

-(void) ccTouchEnded:(UITouch *)touch withEvent:(UIEvent *)event
{
    CCNode *node=[self getChildByTag:UILayerTagFrameSprite];
    ((CCSprite*)node).color=ccWHITE;
}

-(void) dealloc
{
    [super dealloc];
}

@end
